<?php
require_once(dirname(__FILE__)."/class.TextField.php");

/**
 * class ColorPicker
 *
 * Allows the user to pick a color
 *
 * @author Rick den Haan
 * @package FormHandler
 * @subpackage Fields
 * @since 02-07-2008
 * @since 16-07-2008 added advanced option by Johan Wiegel thanks to Winus van Heumen
 */
class ColorPicker extends TextField
{
	var $sTitleAdd = "";
	var $_bAdvanced;

	/**
     * Creates a color picker field
     *
     * @param FormHandler $oForm
     * @param string $sName
     * @return ColorPicker
     */
	function ColorPicker( &$oForm, $sName, $bAdvanced = false )
	{
		parent::TextField(&$oForm, $sName);

		static $bSetJSadvanced = false;
		static $bSetJSsimple = false;

		if( isset( $bAdvanced ) AND $bAdvanced == true )
		{
			$this->_bAdvanced = 1;
			$this->sTitleAdd = '';
			if(!$bSetJSadvanced)
			{
				// include the needed javascript
				$bSetJSadvanced = true;

				$oForm->_setJS("var FH_HTML_DIR = '".FH_FHTML_DIR."';", false);
				$oForm->_setJS(FH_FHTML_DIR."js/prototype.js", true);
				$oForm->_setJS(FH_FHTML_DIR."js/colormethods.js", true);
				$oForm->_setJS(FH_FHTML_DIR."js/colorvaluepicker.js", true);
				$oForm->_setJS(FH_FHTML_DIR."js/slider.js", true);
				$oForm->_setJS(FH_FHTML_DIR."js/advanced_colorpicker.js", true);
			}
		}
		else
		{
			$this->_bAdvanced = false;
			$this->sTitleAdd = " <a href=\"javascript:pickColor('{$this->_sName}lnk');\" id=\"{$this->_sName}lnk\" style=\"border: 1px solid #000000; font-family:Verdana; font-size:10px; text-decoration: none;\">&nbsp;&nbsp;&nbsp;</a>";
			if(!$bSetJSsimple)
			{
				// include the needed javascript
				$bSetJSsimple = true;
				$oForm->_setJS(FH_FHTML_DIR."js/colorpicker.js", true);
			}
		}
	}

	/**
     * ColorPicker::getField()
     *
     * Return the HTML of the field
     *
     * @return string: the html of the field
     * @access public
     * @author Rick den Haan
     */
	function getField()
	{
		// view mode enabled ?
		if( $this -> getViewMode() )
		{
			// get the view value..
			return $this -> _getViewValue();
		}

		if( isset( $this->_bAdvanced ) AND $this->_bAdvanced == true )
		{
			$sContent = file_get_contents(realpath(dirname(__FILE__)."/../")."/FHTML/images/ColorPicker/htmlColorpicker.tpl");
			$aReplaces = array(	'/%%sFH_HTML%%/'	 =>	FH_FHTML_DIR,
			'/%%sFIELD_TITLE%%/' =>	$this->_sName,
			'/%%sFIELD_VALUE%%/' => (!empty($this->_mValue) ? $this->_mValue : "000000"),
			'/%%sEXTRA%%/' 		 => $this->_sExtra);
			return preg_replace(array_keys($aReplaces), array_values($aReplaces), $sContent);
		}
		else
		{
			return sprintf(
			'<input type="text" name="%s" id="%1$s" value="%s" size="%d" %s/>%s',
			$this->_sName,
			(isset($this->_mValue) ? htmlspecialchars($this->_mValue):''),
			$this->_iSize,
			(!empty($this->_iMaxlength) ? 'maxlength="'.$this->_iMaxlength.'" ':'').
			(isset($this->_iTabIndex) ? 'tabindex="'.$this->_iTabIndex.'" ' : '').
			(isset($this->_sExtra) ? ' '.$this->_sExtra.' ' :''),
			(isset($this->_sExtraAfter) ? $this->_sExtraAfter :'')
			);
		}
	}
}
?>